
[![N|Python](https://www.python.org/static/community_logos/python-powered-w-100x40.png)](https://www.python.org)

[![CircleCI](https://circleci.com/gh/fusion-energy/paramak/tree/main.svg?style=svg)](https://circleci.com/gh/fusion-energy/paramak/tree/main)
[![CI with docker build](https://github.com/fusion-energy/paramak/actions/workflows/ci_with_docker_build.yml/badge.svg?branch=main)](https://github.com/fusion-energy/paramak/actions/workflows/ci_with_docker_build.yml)
[![CI with install](https://github.com/fusion-energy/paramak/actions/workflows/ci_with_install.yml/badge.svg?branch=main)](https://github.com/fusion-energy/paramak/actions/workflows/ci_with_install.yml)

[![codecov](https://codecov.io/gh/fusion-energy/paramak/branch/main/graph/badge.svg)](https://codecov.io/gh/fusion-energy/paramak)

[![Code Grade](https://www.code-inspector.com/project/25342/score/svg)](https://frontend.code-inspector.com/public/project/25342/paramak/dashboard)
[![Code Grade](https://www.code-inspector.com/project/25342/status/svg)](https://frontend.code-inspector.com/public/project/25342/paramak/dashboard)


[![Documentation Status](https://readthedocs.org/projects/paramak/badge/?version=main)](https://paramak.readthedocs.io/en/main/?badge=main)


[![Upload Python Package](https://github.com/fusion-energy/paramak/actions/workflows/python-publish.yml/badge.svg)](https://github.com/fusion-energy/paramak/actions/workflows/python-publish.yml)
[![PyPI](https://img.shields.io/pypi/v/paramak?color=brightgreen&label=pypi&logo=grebrightgreenen&logoColor=green)](https://pypi.org/project/paramak/)

[![docker-publish-release](https://github.com/fusion-energy/paramak/actions/workflows/docker_publish.yml/badge.svg)](https://github.com/fusion-energy/paramak/actions/workflows/docker_publish.yml)

[![DOI](https://zenodo.org/badge/269635577.svg)](https://zenodo.org/badge/latestdoi/269635577)

# Paramak

The Paramak python package allows rapid production of 3D CAD models of fusion
reactors. The purpose of the Paramak is to provide geometry for parametric
studies. The paramak can created geometry in standard CAD formats such as STP,
STL and Brep.

:point_right: [Documentation](https://paramak.readthedocs.io)

:point_right: [Video presentation](https://www.youtube.com/embed/fXboew3U7rw)

:point_right: [Installation](https://paramak.readthedocs.io/en/main/#system-installation)

:point_right: [Publication](https://f1000research.com/articles/10-27/v1)

:point_right: [Docker images](https://github.com/fusion-energy/paramak/pkgs/container/paramak)
